--------------------------------------------------------------------
-- Interface Options Panel
--------------------------------------------------------------------


---------------------------
-- create panels
---------------------------
function Glance.Functions.createPanels()
	for i=1,#Glance.Panels do
		local title, desc, func  = unpack(Glance.Panels[i])
		Glance.Functions.createPanel(title, desc, func)
	end
end
function Glance.Functions.createPanel(title, desc, func)
	Glance.Variables.Panels = Glance.Variables.Panels + 1
	local i = Glance.Variables.Panels
	local parent
	if i==1 then parent = UIParent else parent = _G["Glance_Panel1"] end
	_G["Glance_Panel"..i] = CreateFrame( "Frame", "Glance_Panel"..i, parent )
	_G["Glance_Panel"..i].name = title
	if i > 1 then _G["Glance_Panel"..i].parent = parent.name end
	InterfaceOptions_AddCategory(_G["Glance_Panel"..i])
	if title ~= nil then
		local t = Glance.Functions.createText(i,0,0,title,"GameFontNormalLarge","")
	end
	if desc ~= nil then
		local d = Glance.Functions.createText(i,0,-20,desc,"GameFontHighlight","")
	end
	if i==2 then
		_G["Glance_Panel"..i]:SetScript('OnShow', function(self) Glance.Frames.Slider:Show() end)
		_G["Glance_Panel"..i]:SetScript('OnHide', function(self) Glance.Frames.Slider:Hide() end)
	end
	if func ~= nil then
		_G["Glance_Panel"..i]:SetScript('OnShow', function(self) func() end)
	end
	return i
end

---------------------------
-- create texts
---------------------------
function Glance.Functions.createTexts()
	for i=1,#Glance.Text do
		local anchor,x,y,text,font,color,name = unpack(Glance.Text[i])
		Glance.Functions.createText(anchor,x,y,text,font,color,name)
	end
end
function Glance.Functions.createText(anchor,x,y,text,font,color,name)
	local fs = _G["Glance_Panel"..anchor]:CreateFontString(name, "ARTWORK", font)
	fs:SetPoint("TOPLEFT", 16+x, -16+y)
	fs:SetHeight(60)
	fs:SetWidth(InterfaceOptionsFramePanelContainer:GetWidth()-30)
	fs:SetNonSpaceWrap(true)
	fs:SetWordWrap(true)
	fs:SetJustifyH("LEFT")
	fs:SetJustifyV("TOP")
	fs:SetText(color..tostring(text))
	--return fs
end

---------------------------
-- create checkboxs
---------------------------
function Glance.Functions.createCheckBoxes()
	for i=1,#Glance.CheckBoxes do
		local parent,x,y,opt,text,desc,func = unpack(Glance.CheckBoxes[i])
		Glance.Functions.createCheckBox(i,parent,x,y,opt,text,desc,func)
	end
end
function Glance.Functions.createCheckBox(i,parent,x,y,opt,text,desc,func)
	_G["chk"..i] = CreateFrame('CheckButton', "Glance_chk"..i, _G["Glance_Panel"..parent], 'InterfaceOptionsCheckButtonTemplate')
	_G["Glance_chk"..i.."Text"]:SetText(text)
	_G["chk"..i]:SetPoint("TOPLEFT", 16+x, -16+y)
	if desc ~= nil then
		local d = Glance.Functions.createText(_G["chk"..i],12,-5,desc,"GameFontHighlightSmall","|cffffff00")
	end
	if func ~= nil then
		_G["chk"..i]:SetScript('OnClick', function(...) Glance.Functions.switchOptionValues(_G["chk"..i],opt); func() end )
	else
		_G["chk"..i]:SetScript('OnClick', function(...) Glance.Functions.switchOptionValues(_G["chk"..i],opt) end )
	end
end

---------------------------
-- panel buttons
---------------------------
function Glance.Functions.createOptionsButton(panel,name,text,x,y,func)
	local btn = CreateFrame("BUTTON", name, _G["Glance_Panel"..panel], "UIPanelButtonTemplate")
	btn:SetHeight(22)
	local fs = btn:CreateFontString()
	local gameFontName,_,_ = GameFontNormal:GetFont()
	fs:SetFont(gameFontName, 11)
	btn:SetFontString(fs)
	btn:SetText(text)
	btn:SetWidth(btn:GetTextWidth()+30)
	btn:SetPoint("TOPLEFT", x, y)
	btn:SetScript("OnClick", function() func() end)
	btn:Show()
end

---------------------------
-- create scrollbars
---------------------------
function Glance.Functions.createScrollBars()
	for i=1,#Glance.Scrollbars do
		local parent,x,y,h,w,n,array,nameIDX,checkedIDX,func = unpack(Glance.Scrollbars[i])
		Glance.Functions.createScrollBar(parent,x,y,h,w,n,array,nameIDX,checkedIDX,func)
	end
end
function Glance.Functions.createScrollBar(parent,x,y,h,w,n,array,nameIDX,checkedIDX,func)
	Glance.Variables.Scrollbars = Glance.Variables.Scrollbars + 1
	local i = Glance.Variables.Scrollbars
	_G["backframe"..i] = CreateFrame( "Frame", "Glance_BF"..i, parent)
	_G["backframe"..i]:SetPoint("TOPLEFT", x, y)
	_G["backframe"..i]:SetHeight(h)
	_G["backframe"..i]:SetWidth(w)
	_G["backframe"..i]:SetBackdrop(Glance.Arrays.backDrop)
	_G["Glance_SB"..i] = CreateFrame( "ScrollFrame", "Glance_SB"..i, _G["backframe"..i], "FauxScrollFrameTemplate")
	_G["Glance_SB"..i]:SetHeight(h)
	_G["Glance_SB"..i]:SetWidth(w-5)
	_G["Glance_SB"..i]:SetPoint("TOPLEFT",5,-8)
	_G["Glance_SB"..i]:SetPoint("BOTTOMRIGHT",-30,8)
	Glance.Functions.createScrollLines(_G["Glance_SB"..i],"Glance_SBE"..i,n,16,16)
	_G["Glance_SB"..i]:SetScript("OnVerticalScroll",function(self,offset) FauxScrollFrame_OnVerticalScroll(self, offset, 16, function() Glance.Functions.updateScrollbar(i,array,nameIDX,checkedIDX,func) end) end)
	_G["Glance_SB"..i]:SetScript("OnShow", function() Glance.Functions.showScrollbar(i,array,nameIDX,checkedIDX,func) end)
	return i
end

---------------------------
-- create scrollbar lines
---------------------------
function Glance.Functions.createScrollLines(parent,name,count,height,width)
	for i=1, count do
		_G[name..i] = CreateFrame('CheckButton', name..i, parent, 'InterfaceOptionsCheckButtonTemplate')
		if i==1 then
			_G[name..i]:SetPoint("TOPLEFT", parent, "TOPLEFT")
		else
			_G[name..i]:SetPoint("TOPLEFT", name..i-1, "BOTTOMLEFT")
		end
		_G[name..i]:SetHeight(height)
		_G[name..i]:SetWidth(width)
	end
end

---------------------------
-- create options
---------------------------
function Glance.Functions.createOptionsPanel()

	-- panel list
	---------------------------
	Glance.Panels[1] = {"Glance",GetAddOnMetadata("Glance","Notes")}
	Glance.Panels[2] = {"General Settings","General configuration settings for Glance."}
	Glance.Panels[3] = {"Modules","Enable or disable the following modules in Glance. Individual options for modules can be accessed via Right-Click. Previously enabled modules will remain in memory until the UI is reloaded."}
	Glance.Panels[4] = {"Profiles","This is a very simple profile tool.  Click Save Profile to save this character's options to the profile.  Some modules do not allow settings to be saved.  The mount list, for instance, would not be the same for every character.  When you login to another character, come back to the Profiles option panel and click Load Profile to load the previously saved options.  Click Reload UI to register the changes."}
	
	-- about text
	---------------------------
	Glance.Text[1] = {1,15,-60,"Version","GameFontNormal",""}
	Glance.Text[2] = {1,15,-75,GetAddOnMetadata("Glance","Version"),"GameFontHighlight",""}
	Glance.Text[3] = {1,15,-110,"Updated","GameFontNormal",""}
	Glance.Text[4] = {1,15,-125,GetAddOnMetadata("Glance","X-Updated"),"GameFontHighlight",""}
	Glance.Text[5] = {1,15,-160,"Author","GameFontNormal",""}
	Glance.Text[6] = {1,15,-175,GetAddOnMetadata("Glance","Author"),"GameFontHighlight",""}
	Glance.Text[7] = {1,15,-210,"Category","GameFontNormal",""}
	Glance.Text[8] = {1,15,-225,GetAddOnMetadata("Glance","X-Category"),"GameFontHighlight",""}
	Glance.Text[9] = {1,15,-260,"New In This Version","GameFontNormal",""}
	Glance.Text[10] = {1,15,-275,GetAddOnMetadata("Glance","X-New"),"GameFontHighlight",""}
	
	-- general options
	---------------------------
	Glance.Text[11] = {2,0,-60,"Move the following to make room for Glance","GameFontNormal",""}
	Glance.Text[12] = {2,0,-75,"Glance will not release any unchecked frames to other addons until the UI is reloaded.","GameFontHighlight",""}
	Glance.CheckBoxes[1] = {2,15,-100,"movePlayer","Player Frame",nil,function() Glance.Functions.moveUI() end}
	Glance.CheckBoxes[2] = {2,15,-120,"moveTarget","Target Frame",nil,function() Glance.Functions.moveUI() end}
	Glance.CheckBoxes[3] = {2,15,-140,"moveBuffs","Buffs",nil,function() Glance.Functions.moveUI() end}
	Glance.CheckBoxes[4] = {2,15,-160,"moveMinimap","Minimap",nil,function() Glance.Functions.moveUI() end}
	
	Glance.Text[13] = {2,0,-200,"Other Options","GameFontNormal",""}
	Glance.CheckBoxes[5] = {2,15,-220,"sendStats","Send stats to party members using Glance",nil}
	Glance.CheckBoxes[6] = {2,15,-240,"timePlayed","Show time played on login",nil}
	Glance.CheckBoxes[7] = {2,15,-260,"gameFont","Use the standard game font (Requires Restart)",nil}
	
	Glance.Text[14] = {2,0,-300,"Select the scale of the Glance bar","GameFontNormal",""}
	Glance.Text[17] = {2,0,-375,"Select the colors of the Glance bar","GameFontNormal",""}
	Glance.Text[18] = {2,45,-396,"Bar Color","GameFontHighlight",""}
	Glance.Text[19] = {2,45,-416,"Bar Color (Combat)","GameFontHighlight",""}
	Glance.Text[20] = {2,45,-436,"Bar Border Color","GameFontHighlight",""}

	-- create the panels
	---------------------------
	Glance.Functions.createPanels()
	
	-- create the buttons
	---------------------------
	Glance.Functions.createOptionsButton(2,"GLance_Panel2_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(3,"GLance_Panel3_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_ReloadUI","RELOAD UI",345,-582,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Save","Save Profile",30,-100,function() Glance.Functions.saveProfile() end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Load","Load Profile",150,-100,function() Glance.Functions.loadProfile() end)
	Glance.Functions.createOptionsButton(4,"GLance_Panel4_Reload","RELOAD UI",270,-100,function() StaticPopup_Show("Glance_RELOADUI") end)
	Glance.Functions.createOptionsButton(2,"GLance_Panel2_Reset","RESET",35,-470,function() 
		local r,g,b,a = unpack(Glance.Variables.defaultFrameColor[1]);
		_G["GlanceSwatch1"].texture:SetTexture(r, g, b, a)
		r,g,b,a = unpack(Glance.Variables.defaultFrameColor[2]);
		_G["GlanceSwatch2"].texture:SetTexture(r, g, b, a)
		r,g,b,a = unpack(Glance.Variables.defaultFrameColor[3]);
		_G["GlanceSwatch3"].texture:SetTexture(r, g, b, a)
		Glance_Global.Options.frameColor = Glance.Variables.defaultFrameColor
		Glance.Functions.setBackground(1)
	end)
	
	-- profile text
	---------------------------
	Glance.Text[15] = {4,0,-130,"Current Profile set to:","GameFontNormal",""}
	Glance.Text[16] = {4,130,-130," ","GameFontHighlight","profile is not set.","Glance_Profile_Text"}
	
	-- create checkbox/scroll
	---------------------------
	Glance.Functions.createTexts()
	Glance.Functions.createCheckBoxes()
	Glance.Functions.createScrollBars()
	
	-- create GO slider
	---------------------------
	Glance.Frames.Slider = CreateFrame("Slider", "Glance.Frames.Slider", Glance_Panel2, "OptionsSliderTemplate")
	Glance.Frames.Slider:ClearAllPoints()
	Glance.Frames.Slider:SetPoint("TOPLEFT", Glance_Panel2, "TOPLEFT", 41, -350)
	Glance.Frames.Slider:SetMinMaxValues(0.5, 1.5)
	Glance.Frames.Slider:SetValue(Glance_Local.Options.frameScale)
	getglobal(Glance.Frames.Slider:GetName() .. "Low"):SetText("smaller")
	getglobal(Glance.Frames.Slider:GetName() .. "High"):SetText("larger")
	if Glance_Local.Options.frameScale == 1 then
		getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText("default")
	else
		getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText(Glance.Functions.roundDecimal(Glance.Frames.Slider:GetValue(),1))
	end
	Glance.Frames.Slider:SetValueStep(0.1)
	Glance.Frames.Slider:SetScript("OnValueChanged", function() Glance.Functions.sliderValueChanged() end) 
	
	--create GO color swatch
	-----------------------
	Glance.Frames.Swatch1 = CreateFrame("BUTTON", "GlanceSwatch1", Glance_Panel2)
	Glance.Frames.Swatch1:SetWidth(16)
	Glance.Frames.Swatch1:SetHeight(16)
	Glance.Frames.Swatch1:SetPoint("TOPLEFT", Glance_Panel2, "TOPLEFT", 35, -410)
	local r,g,b,a = unpack(Glance_Global.Options.frameColor[1])
	
	local t = Glance.Frames.Swatch1:CreateTexture(nil, "BACKGROUND")
	t:SetTexture(r,g,b,a)
	t:SetWidth(16)
	t:SetHeight(16)
	t:SetAllPoints(Glance.Frames.Swatch1)
	Glance.Frames.Swatch1.texture = t 
	
	Glance.Frames.Swatch1:SetScript("OnClick", function(self, button, down) 
		local r,g,b,a = unpack(Glance_Global.Options.frameColor[1])
		Glance.Variables.currentSwatch = 1;
		Glance.Variables.currentFrame = Glance.Frames.topFrame;
		Glance.Functions.ShowColorPicker(r,g,b,a); 
	end)
	Glance.Frames.Swatch1:SetScript("OnEnter", function(...) SetCursor("CAST_CURSOR") end)
	Glance.Frames.Swatch1:SetScript("OnLeave", function(...) SetCursor("POINT_CURSOR") end)
	
	--create GO color Swatch2
	-----------------------
	Glance.Frames.Swatch2 = CreateFrame("BUTTON", "GlanceSwatch2", Glance_Panel2)
	Glance.Frames.Swatch2:SetWidth(16)
	Glance.Frames.Swatch2:SetHeight(16)
	Glance.Frames.Swatch2:SetPoint("TOPLEFT", Glance_Panel2, "TOPLEFT", 35, -430)
	local r,g,b,a = unpack(Glance_Global.Options.frameColor[2])
		
	local t = Glance.Frames.Swatch2:CreateTexture(nil, "BACKGROUND")
	t:SetTexture(r,g,b,a)
	t:SetWidth(16)
	t:SetHeight(16)
	t:SetAllPoints(Glance.Frames.Swatch2)
	Glance.Frames.Swatch2.texture = t 
	
	Glance.Frames.Swatch2:SetScript("OnClick", function(self, button, down) 
		local r,g,b,a = unpack(Glance_Global.Options.frameColor[2])
		Glance.Variables.currentSwatch = 2;
		Glance.Variables.currentFrame = Glance.Frames.topFrame;
		Glance.Functions.ShowColorPicker(r,g,b,a); 
	end)
	Glance.Frames.Swatch2:SetScript("OnEnter", function(...) SetCursor("CAST_CURSOR") end)
	Glance.Frames.Swatch2:SetScript("OnLeave", function(...) SetCursor("POINT_CURSOR") end)
	
	--create GO color Swatch3
	-----------------------
	Glance.Frames.Swatch3 = CreateFrame("BUTTON", "GlanceSwatch3", Glance_Panel2)
	Glance.Frames.Swatch3:SetWidth(16)
	Glance.Frames.Swatch3:SetHeight(16)
	Glance.Frames.Swatch3:SetPoint("TOPLEFT", Glance_Panel2, "TOPLEFT", 35, -450)
	local r,g,b,a = unpack(Glance_Global.Options.frameColor[3])
	
	local t = Glance.Frames.Swatch3:CreateTexture(nil, "BACKGROUND")
	t:SetTexture(r,g,b,a)
	t:SetWidth(16)
	t:SetHeight(16)
	t:SetAllPoints(Glance.Frames.Swatch3)
	Glance.Frames.Swatch3.texture = t 
	
	Glance.Frames.Swatch3:SetScript("OnClick", function(self, button, down) 
		local r,g,b,a = unpack(Glance_Global.Options.frameColor[3])
		Glance.Variables.currentSwatch = 3;
		Glance.Variables.currentFrame = Glance.Frames.topFrame;
		Glance.Functions.ShowColorPicker(r,g,b,a); 
	end)
	Glance.Frames.Swatch3:SetScript("OnEnter", function(...) SetCursor("CAST_CURSOR") end)
	Glance.Frames.Swatch3:SetScript("OnLeave", function(...) SetCursor("POINT_CURSOR") end)



	-- load button options
	---------------------------
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].options then
			Glance.Functions[k].options()
		end
	end
	
	-- reload UI dialog
	---------------------------
    StaticPopupDialogs["Glance_RELOADUI"] = {
        text = "Reload your User Interface?",
        button1 = TEXT(ACCEPT),
        button2 = TEXT(CANCEL),
        OnAccept = function()
            ReloadUI()
        end,
        OnCancel = function(data, reason)
            if (reason == "timeout") then
                ReloadUI()
            else
                StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted = false
            end
        end,
        OnHide = function()
            if (StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted) then
                ReloadUI();
            end
        end,
        OnShow = function()
            StaticPopupDialogs["Glance_RELOADUI"].reloadAccepted = true;
        end,
        timeout = 5,
        hideOnEscape = 1,
        exclusive = 1,
        whileDead = 1
    }
	
	-- profile stored text
	---------------------------
	if Glance_Profile.realm ~= nil and Glance_Profile.name ~= nil and Glance_Profile.date ~= nil and Glance_Profile.time ~= nil then
		_G["Glance_Profile_Text"]:SetText(Glance_Profile.realm.." \\ "..Glance_Profile.name.." on "..Glance_Profile.date.." at "..Glance_Profile.time)
	end
end

---------------------------
-- slider change
---------------------------
function Glance.Functions.sliderValueChanged()
	local scale = Glance.Functions.roundDecimal(Glance.Frames.Slider:GetValue(),1)
	if scale == 1 then
		getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText("default")
	else
		getglobal(Glance.Frames.Slider:GetName() .. "Text"):SetText(scale)
	end
	Glance_Local.Options.frameScale = scale
	Glance.Frames.topFrame:SetScale(scale)
	Glance.Functions.moveUI()
	Glance.Functions.updateAll()
end

---------------------------
-- scrollbar overflow fix
---------------------------
function Glance.Functions.showScrollbar(sbIDX,array,nameIDX,checkedIDX,func)
	if Glance.Variables.overflowFix then
		Glance.Functions.updateScrollbar(sbIDX,array,nameIDX,checkedIDX,func)
	else
		return
	end
end

---------------------------
-- scrollbar update
---------------------------
function Glance.Functions.updateScrollbar(sbIDX,array,nameIDX,checkedIDX,func) --Glance_Local.mounts,1,3,Glance.Functions.setPreferredMount()
	FauxScrollFrame_Update(_G["Glance_SB"..sbIDX],#array,20,16);  -- (frame, numItems/lines, numToDisplay, pixelheight/line) -- this is the 195 count...
	local line, lineplusoffset, thisArray
	for line=1,20 do
		lineplusoffset = line + FauxScrollFrame_GetOffset(_G["Glance_SB"..sbIDX]);
		if lineplusoffset <= #array then
			thisArray =  array[lineplusoffset]
			-- problem here by not checking the array.  mods can still be loaded and unchecked
			--if array == Glance.Arrays.Modules then
			--	thisArray[checkedIDX] = IsAddOnLoaded("Glance_"..thisArray[2])
			--end
			_G[getglobal("Glance_SBE"..sbIDX..line):GetName().."Text"]:SetText(thisArray[nameIDX])
			_G["Glance_SBE"..sbIDX..line]:SetChecked(thisArray[checkedIDX])
			_G["Glance_SBE"..sbIDX..line]:SetScript('OnClick', function(...) func(line) end )
			_G["Glance_SBE"..sbIDX..line]:Show();
		else
			_G["Glance_SBE"..sbIDX..line]:Hide();
		end
	end
	Glance.Variables.overflowFix = false
	_G["Glance_SB"..sbIDX]:Show()
end

---------------------------
-- preload checkboxes
---------------------------
function Glance.Functions.setOptionValues()
	for i=1,#Glance.CheckBoxes do
		_G["chk"..i]:SetChecked(Glance_Local.Options[Glance.CheckBoxes[i][4]])
	end
end

---------------------------
-- checkbox onclick
---------------------------
function Glance.Functions.switchOptionValues(btn,val)
	if btn:GetChecked() == nil then
		Glance_Local.Options[val] = false
	else
		Glance_Local.Options[val] = true
	end
	--Glance.Functions.updateAll()
end

---------------------------
-- save profile
---------------------------
function Glance.Functions.saveProfile()
	local hour, min = GetGameTime()
	Glance_Profile.realm = GetRealmName()
	Glance_Profile.name  = UnitName("player")
	Glance_Profile.date  = date("%m/%d/%y")
	Glance_Profile.time  = Glance.Functions.GetHour(hour)..":"..Glance.Functions.GetMin(min).." "..Glance.Functions.GetAMPM(hour).." (S)"
	Glance_Profile.Options = Glance_Local.Options
	Glance_Profile.button  = Glance_Local.button
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].save.allowProfile then
			if Glance.Buttons[k].save.perCharacter ~= nil then
				for key, val in pairs(Glance.Buttons[k].save.perCharacter) do
					if Glance_Profile[k] == nil then Glance_Profile[k] = {} end
					Glance_Profile[k][key] = Glance.Buttons[k].save.perCharacter[key]
				end
			end
		end
	end
	StaticPopupDialogs["Glance_Saved"] = {
		text = "Your settings have been saved to the profile.",
        button1 = TEXT(OKAY),
        timeout = 5,
        hideOnEscape = 1,
        exclusive = 1,
        whileDead = 1
    }
	StaticPopup_Show("Glance_Saved")
	_G["Glance_Profile_Text"]:SetText(Glance_Profile.realm.." \\ "..Glance_Profile.name.." on "..Glance_Profile.date.." at "..Glance_Profile.time)
end

---------------------------
-- load profile
---------------------------
function Glance.Functions.loadProfile()
	Glance_Local.Options = Glance_Profile.Options
	Glance_Local.button = Glance_Profile.button
	Glance.Variables.button = Glance_Profile.button
	for k, v in pairs(Glance.Buttons) do
		if Glance.Buttons[k].save.allowProfile then
			if Glance.Buttons[k].save.perCharacter ~= nil then
				for key, val in pairs(Glance.Buttons[k].save.perCharacter) do
					if Glance_Profile[k] ~= nil then 
					Glance.Buttons[k].save.perCharacter[key] = Glance_Profile[k][key]
					end
				end
			end
		end
	end
	Glance.Functions.positionButtons()
	Glance.Functions.updateAll()
	StaticPopupDialogs["Glance_Loaded"] = {
		text = "Your settings have been loaded from the profile.",
        button1 = TEXT(OKAY),
        timeout = 5,
        hideOnEscape = 1,
        exclusive = 1,
        whileDead = 1
    }
	StaticPopup_Show("Glance_Loaded")
end


---------------------------
-- Hour function
---------------------------
function Glance.Functions.GetHour(hour)
	if hour > 12 then
		hour = hour - 12
	end
	if hour == 0 then
		hour = 12
	end
	return hour
end

---------------------------
-- Hour function
---------------------------
function Glance.Functions.GetMin(min)
	if min < 10 then
		return "0"..min
	end
	return min
end

---------------------------
-- DST function
---------------------------
function Glance.Functions.GetAMPM(hour)
	if hour < 12 then
		return "AM"
	else
		return "PM"
	end
end


---------------------------
-- colorpicker function
---------------------------
function Glance.Functions.ShowColorPicker(r, g, b, a)
	ColorPickerFrame.hasOpacity = true
	ColorPickerFrame.opacity = a;
	ColorPickerFrame.previousValues = {r,g,b,a};
	ColorPickerFrame:SetColorRGB(r,g,b);
	ColorPickerFrame.func, ColorPickerFrame.opacityFunc, ColorPickerFrame.cancelFunc = Glance.Functions.ColorPickerUpdate, Glance.Functions.ColorPickerOkay, Glance.Functions.ColorPickerCancel;
	ColorPickerFrame:Show();
end


---------------------------
-- colorpicker cancel
---------------------------
function Glance.Functions.ColorPickerCancel(restore)
	local r,g,b,a;
	if restore then -- cancel
		r,g,b,a = unpack(restore);
		_G["GlanceSwatch"..Glance.Variables.currentSwatch].texture:SetTexture(r, g, b, a)
		Glance_Global.Options.frameColor[Glance.Variables.currentSwatch] = {r, g, b, a}
		if Glance.Variables.currentSwatch == 3 then
			Glance.Functions.setBackground(1)
		else
			Glance.Functions.setBackground(Glance.Variables.currentSwatch)
		end
	end
end

---------------------------
-- colorpicker okay
---------------------------
function Glance.Functions.ColorPickerOkay()
	local r,g,b,a;
	a,r,g,b = OpacitySliderFrame:GetValue(), ColorPickerFrame:GetColorRGB();
	_G["GlanceSwatch"..Glance.Variables.currentSwatch].texture:SetTexture(r, g, b, a)
	Glance_Global.Options.frameColor[Glance.Variables.currentSwatch] = {r, g, b, a}
	Glance.Functions.setBackground(1)
end

---------------------------
-- colorpicker update
---------------------------
function Glance.Functions.ColorPickerUpdate()
	local r,g,b,a;
	a,r,g,b = OpacitySliderFrame:GetValue(), ColorPickerFrame:GetColorRGB();
	_G["GlanceSwatch"..Glance.Variables.currentSwatch].texture:SetTexture(r, g, b, a)
	Glance_Global.Options.frameColor[Glance.Variables.currentSwatch] = {r, g, b, a}
	Glance.Functions.setBackground(Glance.Variables.currentSwatch)
end


Glance.Functions.createOptionsPanel()
Glance.Functions.setOptionValues()